import * as React from 'react';

interface ShowProps {
   children:React.ReactElement;
}

export const Show: React.FC<ShowProps> & {
       When: React.FC<ShowWhenProps>;
       Else: React.FC<ShowElseProps>;
   } = (props) => {

   let when: React.ReactElement | null = null;
   let otherwise: React.ReactElement | null = null;

   React.Children.forEach(props.children, (child) => {
       const childElement = child as React.ReactElement;

       if (childElement.props.isTrue === undefined) {
           otherwise = childElement;
       } else if (!when && childElement.props.isTrue === true) {
           when = childElement;
       }
   });

   return when || otherwise;
};

interface ShowWhenProps {
   isTrue: boolean;
   children:React.ReactElement;
}

interface ShowElseProps {
   render?: React.ReactElement<any, any>;
   children?: React.ReactElement<any, any>;
}

Show.When = ({isTrue, children}: ShowWhenProps) => {
   return isTrue ? <>{children}</> : null;
};

Show.Else = ({ render, children }: ShowElseProps) => {
    return render ? render : children || null; // Call render as a function
  };
